@@ -11,16 +11,19 @@ useful, but WITHOUT ANY WARRANTY; without even the implied
 warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR 
 PURPOSE.  See the GNU General Public License for more details.
  
-*/
+ */
 
 package com.clustercontrol.accesscontrol.bean;
 
+import java.io.File;
+import java.io.FileInputStream;
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Properties;
 
 /**
  * HinemosのRole(権限)種類を定数として格納するクラス<BR>
- *
+ * 
  * @version 2.1.0
  * @since 2.0.0
  */
@@ -31,9 +34,9 @@ public class RoleConstant {
 	public static List<String> m_readRoles = new ArrayList<String>();
 	/** WriteRoleリスト */
 	public static List<String> m_writeRoles = new ArrayList<String>();
-	/** ExecRoleリスト*/
+	/** ExecRoleリスト */
 	public static List<String> m_execRoles = new ArrayList<String>();
-	
+
 	/** Hinemosユーザ */
 	public static final String HINEMOS_USER = "HinemosUser";
 	/** リポジトリ - 参照権限 */
@@ -126,7 +129,13 @@ public class RoleConstant {
 	public static final String MAINTENANCE_READ = "MaintenanceRead";
 	/** メンテナンス - 設定権限 */
 	public static final String MAINTENANCE_WRITE = "MaintenanceWrite";
-	
+	/** 仮想化管理 - 参照権限 */
+	public static final String VMMANAGEMENT_READ = "VmManagementRead";
+	/** 仮想化管理 - 設定権限 */
+	public static final String VMMANAGEMENT_WRITE = "VmManagementWrite";
+	/** 仮想化管理 - 実行権限 */
+	public static final String VMMANAGEMENT_EXECUTE = "VmManagementExecute";
+
 	static {
 		m_roles.add(HINEMOS_USER);
 		m_roles.add(REPOSITORY_READ);
@@ -172,19 +181,32 @@ public class RoleConstant {
 		m_roles.add(SNMPTRAP_MONITOR_WRITE);
 		m_roles.add(MAINTENANCE_READ);
 		m_roles.add(MAINTENANCE_WRITE);
-		
+
+		// VM Management option -begin-
+		Properties properties = new Properties();
+		String etcdir = System.getProperty("hinemos.manager.etc.dir");
+		String propertyFile = etcdir + File.separator + "option.properties";
+		try {
+			properties.load(new FileInputStream(propertyFile));
+
+			m_roles.add(VMMANAGEMENT_READ);
+			m_roles.add(VMMANAGEMENT_WRITE);
+			m_roles.add(VMMANAGEMENT_EXECUTE);
+		} catch (Exception e) {
+		}
+		// VM Management option -end-
+
 		String serverName = System.getProperty("jboss.server.name");
-		if(serverName != null && serverName.equals("all")){
+		if (serverName != null && serverName.equals("all")) {
 			m_roles.add(TROUBLE_DETECTION_READ);
 			m_roles.add(TROUBLE_DETECTION_WRITE);
 		}
-		
-	
+
 		/** WriteRoleリスト */
-		//参照権限
+		// 参照権限
 		m_readRoles.add(REPOSITORY_READ);
 		m_readRoles.add(ACCESSCONTROL_READ);
-		m_readRoles.add(JOBMANAGEMENT_READ);	
+		m_readRoles.add(JOBMANAGEMENT_READ);
 		m_readRoles.add(COLLECTIVERUN_READ);
 		m_readRoles.add(PERFORMANCE_READ);
 		m_readRoles.add(MONITOR_READ);
@@ -202,8 +224,9 @@ public class RoleConstant {
 		m_readRoles.add(LOG_TRANSFER_READ);
 		m_readRoles.add(SNMPTRAP_MONITOR_READ);
 		m_readRoles.add(MAINTENANCE_READ);
+		m_readRoles.add(VMMANAGEMENT_READ);
 
-		//設定権限
+		// 設定権限
 		m_writeRoles.add(REPOSITORY_WRITE);
 		m_writeRoles.add(ACCESSCONTROL_WRITE);
 		m_writeRoles.add(JOBMANAGEMENT_WRITE);
@@ -224,18 +247,18 @@ public class RoleConstant {
 		m_writeRoles.add(LOG_TRANSFER_WRITE);
 		m_writeRoles.add(SNMPTRAP_MONITOR_WRITE);
 		m_writeRoles.add(MAINTENANCE_WRITE);
-		
-		
-		//実行権限
+		m_writeRoles.add(VMMANAGEMENT_WRITE);
+
+		// 実行権限
 		m_execRoles.add(JOBMANAGEMENT_EXECUTE);
 		m_execRoles.add(COLLECTIVERUN_EXECUTE);
 		m_execRoles.add(PERFORMANCE_EXECUTE);
-		
-		
-		if(serverName != null && serverName.equals("all")){
+		m_execRoles.add(VMMANAGEMENT_EXECUTE);
+
+		if (serverName != null && serverName.equals("all")) {
 			m_readRoles.add(TROUBLE_DETECTION_READ);
 			m_writeRoles.add(TROUBLE_DETECTION_WRITE);
-		}	
+		}
 	}
 
 	/**
@@ -246,38 +269,35 @@ public class RoleConstant {
 	public static List<String> getRoles() {
 		return m_roles;
 	}
-	
-	
+
 	/**
 	 * Roleリストを返します。
 	 * 
 	 * @return Roleリスト
 	 */
 	public static List<String> getReadRoles() {
-		
+
 		return m_readRoles;
 	}
-	
-	
+
 	/**
 	 * Roleリストを返します。
 	 * 
 	 * @return Roleリスト
 	 */
 	public static List<String> getWriteRoles() {
-		
+
 		return m_writeRoles;
 	}
-	
+
 	/**
 	 * Roleリストを返します。
 	 * 
 	 * @return Roleリスト
 	 */
 	public static List<String> getExecRoles() {
-		
+
 		return m_execRoles;
 	}
-	
-	
+
 }
