@@ -15,11 +15,14 @@ PURPOSE.  See the GNU General Public License for more details.
 
 package com.clustercontrol.accesscontrol.factory;
 
+import java.io.File;
+import java.io.FileInputStream;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Iterator;
 import java.util.List;
 import java.util.Locale;
+import java.util.Properties;
 
 import javax.ejb.FinderException;
 import javax.naming.NamingException;
@@ -126,6 +129,9 @@ public class UserProperty extends RoleConstant{
 	 *    <li>通知 - 設定（孫。チェックボックス）</li>
 	 *    <li>重要度判定 - 参照（孫。チェックボックス）</li>
 	 *    <li>重要度判定 - 設定（孫。チェックボックス）</li>
+	 *    <li>仮想化管理 - 参照（孫。チェックボックス）</li>
+	 *    <li>仮想化管理 - 設定（孫。チェックボックス）</li>
+	 *    <li>仮想化管理 - 実行（孫。チェックボックス）</li>
 	 *    <li>障害検知 - 参照（孫。チェックボックス）</li>
 	 *    <li>障害検知 - 設定（孫。チェックボックス）</li>
 	 *   </ul>
@@ -204,6 +210,7 @@ public class UserProperty extends RoleConstant{
 						
 						for(int i = 0; i < roleList.size(); i++){
 							String roleName = roleList.get(i);
+							
 							if(role.getCn().compareTo(roleName) == 0){
 								propertyList = PropertyUtil.getProperty(accessProperty, roleName);
 								if(propertyList.size() > 0){
@@ -283,6 +290,9 @@ public class UserProperty extends RoleConstant{
 	 *    <li>通知 - 設定（孫。チェックボックス）</li>
 	 *    <li>重要度判定 - 参照（孫。チェックボックス）</li>
 	 *    <li>重要度判定 - 設定（孫。チェックボックス）</li>
+	 *    <li>仮想化管理 - 参照（孫。チェックボックス）</li>
+	 *    <li>仮想化管理 - 設定（孫。チェックボックス）</li>
+	 *    <li>仮想化管理 - 実行（孫。チェックボックス）</li>
 	 *    <li>障害検知 - 参照（孫。チェックボックス）</li>
 	 *    <li>障害検知 - 設定（孫。チェックボックス）</li>
 	 *   </ul>
@@ -451,6 +461,15 @@ public class UserProperty extends RoleConstant{
 		//メンテナンス設定
 		Property maintenanceWrite =
 			new Property(MAINTENANCE_WRITE, Messages.getString("maintenance.write", locale), PropertyConstant.EDITOR_BOOL);
+		//仮想化管理参照
+		Property vmManagementRead =
+			new Property(VMMANAGEMENT_READ, Messages.getString("vm.management.read", locale), PropertyConstant.EDITOR_BOOL);
+		//仮想化管理設定
+		Property vmManagementWrite =
+			new Property(VMMANAGEMENT_WRITE, Messages.getString("vm.management.write", locale), PropertyConstant.EDITOR_BOOL);
+		//仮想化管理実行
+		Property vmManagementExecute =
+			new Property(VMMANAGEMENT_EXECUTE, Messages.getString("vm.management.execute", locale), PropertyConstant.EDITOR_BOOL);
 		//障害検知参照
 		Property troubleDetectionRead =
 			new Property(TROUBLE_DETECTION_READ, Messages.getString("trouble.detection.read", locale), PropertyConstant.EDITOR_BOOL);
@@ -512,6 +531,9 @@ public class UserProperty extends RoleConstant{
 		priorityJudgmentWrite.setValue(Boolean.valueOf(false));
 		maintenanceRead.setValue(Boolean.valueOf(false));
 		maintenanceWrite.setValue(Boolean.valueOf(false));
+		vmManagementRead.setValue(Boolean.valueOf(false));
+		vmManagementWrite.setValue(Boolean.valueOf(false));
+		vmManagementExecute.setValue(Boolean.valueOf(false));
 		troubleDetectionRead.setValue(Boolean.valueOf(false));
 		troubleDetectionWrite.setValue(Boolean.valueOf(false));
 
@@ -562,6 +584,9 @@ public class UserProperty extends RoleConstant{
 			priorityJudgmentWrite.setModify(PropertyConstant.MODIFY_OK);
 			maintenanceRead.setModify(PropertyConstant.MODIFY_OK);
 			maintenanceWrite.setModify(PropertyConstant.MODIFY_OK);
+			vmManagementRead.setModify(PropertyConstant.MODIFY_OK);
+			vmManagementWrite.setModify(PropertyConstant.MODIFY_OK);
+			vmManagementExecute.setModify(PropertyConstant.MODIFY_OK);
 			troubleDetectionRead.setModify(PropertyConstant.MODIFY_OK);
 			troubleDetectionWrite.setModify(PropertyConstant.MODIFY_OK);
 		}
@@ -610,6 +635,9 @@ public class UserProperty extends RoleConstant{
 			priorityJudgmentWrite.setModify(PropertyConstant.MODIFY_OK);
 			maintenanceRead.setModify(PropertyConstant.MODIFY_OK);
 			maintenanceWrite.setModify(PropertyConstant.MODIFY_OK);
+			vmManagementRead.setModify(PropertyConstant.MODIFY_OK);
+			vmManagementWrite.setModify(PropertyConstant.MODIFY_OK);
+			vmManagementExecute.setModify(PropertyConstant.MODIFY_OK);
 			troubleDetectionRead.setModify(PropertyConstant.MODIFY_OK);
 			troubleDetectionWrite.setModify(PropertyConstant.MODIFY_OK);
 		}
@@ -673,6 +701,22 @@ public class UserProperty extends RoleConstant{
 		access.addChildren(maintenanceRead);
 		access.addChildren(maintenanceWrite);
 		
+		//VM Management option -begin-
+		Properties properties = new Properties();
+		String etcdir = System.getProperty("hinemos.manager.etc.dir");
+		String propertyFile = etcdir + File.separator + "option.properties";
+		try{
+			properties.load(new FileInputStream(propertyFile));
+			
+			if("true".equals(properties.getProperty("add.option.vm", "false"))){
+				access.addChildren(vmManagementRead);
+				access.addChildren(vmManagementWrite);
+				access.addChildren(vmManagementExecute);
+			}
+		} catch (Exception e) {
+		}
+		// VM Management option -end-
+		
 		String serverName = System.getProperty("jboss.server.name");
 		if(serverName.equals("all")){
 			access.addChildren(troubleDetectionRead);
