@@ -18,8 +18,6 @@ package com.clustercontrol.http.dialog;
 import java.util.ArrayList;
 
 import org.eclipse.swt.SWT;
-import org.eclipse.swt.events.SelectionAdapter;
-import org.eclipse.swt.events.SelectionEvent;
 import org.eclipse.swt.graphics.Point;
 import org.eclipse.swt.layout.GridData;
 import org.eclipse.swt.layout.GridLayout;
@@ -32,10 +30,9 @@ import org.eclipse.swt.widgets.Shell;
 import org.eclipse.swt.widgets.Text;
 
 import com.clustercontrol.bean.DataRangeConstant;
+import com.clustercontrol.bean.HinemosModuleConstant;
 import com.clustercontrol.bean.MonitorBlockConstant;
-import com.clustercontrol.bean.MonitorConstant;
 import com.clustercontrol.bean.ValidConstant;
-import com.clustercontrol.bean.YesNoConstant;
 import com.clustercontrol.composite.PositiveNumberVerifyListener;
 import com.clustercontrol.composite.StringVerifyListener;
 import com.clustercontrol.dialog.CommonDialog;
@@ -51,16 +48,16 @@ import com.clustercontrol.monitor.run.bean.MonitorNumericValueInfo;
 import com.clustercontrol.monitor.run.bean.MonitorTypeConstant;
 import com.clustercontrol.monitor.run.composite.MonitorBasicScopeComposite;
 import com.clustercontrol.monitor.run.composite.MonitorRuleComposite;
-import com.clustercontrol.monitor.run.composite.NumericRunJobComposite;
 import com.clustercontrol.monitor.run.composite.NumericValueInfoComposite;
 import com.clustercontrol.monitor.run.composite.StringValueInfoComposite;
+import com.clustercontrol.notify.bean.NotifyRelationInfo;
 import com.clustercontrol.notify.composite.NotifyInfoComposite;
 import com.clustercontrol.util.Messages;
 
 /**
  * HTTP監視作成・変更ダイアログクラス<BR>
  * 
- * @version 2.2.0
+ * @version 3.0.0
  * @since 2.1.0
  */
 public class HttpCreateDialog extends CommonDialog {
@@ -103,8 +100,6 @@ public class HttpCreateDialog extends CommonDialog {
     /** ジョブ実行 */
     private Button m_checkJobRun = null;
     
-    /** ジョブ実行情報 */
-    private NumericRunJobComposite m_jobRun = null;
     
     /** この設定を有効にする */
     private Button confirmValid = null;
@@ -376,40 +371,7 @@ public class HttpCreateDialog extends CommonDialog {
 		// 数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
 			
-			// ジョブ実行
-	        this.m_checkJobRun = new Button(groupNotifyAttribute, SWT.CHECK);
-	        gridData = new GridData();
-	        gridData.horizontalSpan = 1;
-	        gridData.horizontalAlignment = GridData.FILL;
-	        gridData.grabExcessHorizontalSpace = true;
-	        m_checkJobRun.setLayoutData(gridData);
-	        m_checkJobRun.setText(Messages.getString("run") + " : ");
-	        m_checkJobRun.addSelectionListener(new SelectionAdapter() {
-	            public void widgetSelected(SelectionEvent e) {
-	            	m_jobRun.setEnabled(m_checkJobRun.getSelection());
-	            }
-	        });
-			
-			// ジョブ実行グループ
-	        Group groupRunJob = new Group(groupNotifyAttribute, SWT.NONE);
-	        layout = new GridLayout(1, true);
-	        layout.marginWidth = 5;
-	        layout.marginHeight = 5;
-	        layout.numColumns = 1;
-	        groupRunJob.setLayout(layout);
-	        gridData = new GridData();
-	        gridData.horizontalSpan = 15;
-	        gridData.horizontalAlignment = GridData.FILL;
-	        gridData.grabExcessHorizontalSpace = true;
-	        groupRunJob.setLayoutData(gridData);
-	        
-	        // 実行（実行，ジョブID，通知抑制と連動，呼出失敗時）
-			this.m_jobRun = new NumericRunJobComposite(groupRunJob, SWT.NONE);
-			gridData = new GridData();
-			gridData.horizontalSpan = 1;
-			gridData.horizontalAlignment = GridData.FILL;
-			gridData.grabExcessHorizontalSpace = true;
-			m_jobRun.setLayoutData(gridData);
+		
 		}
 		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
@@ -440,7 +402,7 @@ public class HttpCreateDialog extends CommonDialog {
 	        groupDefResult.setLayoutData(gridData);
 			
 	        // ノード単位の重要度
-	        ArrayList tableDefine = GetHttpStringValueListTableDefine.get();
+	        ArrayList<Object> tableDefine = GetHttpStringValueListTableDefine.get();
 			this.m_stringValueInfo = new StringValueInfoComposite(groupDefResult, SWT.NONE, tableDefine);
 			gridData = new GridData();
 			gridData.horizontalSpan = 1;
@@ -527,10 +489,11 @@ public class HttpCreateDialog extends CommonDialog {
             this.m_textTimeout.setText(Integer.toString(httpInfo.getTimeout()));
         }
         
-        // 通知情報の属性
-        if (monitor.getNotifyId() != null) {
-        	this.m_notifyInfo.setText(monitor.getNotifyId());
-        }
+    	
+        //通知情報の設定
+        if(monitor.getNotifyId() != null)
+        this.m_notifyInfo.setNotify(monitor.getNotifyId());
+        
         if (monitor.getApplication() != null) {
         	this.m_notifyInfo.setApplication(monitor.getApplication());
         }
@@ -541,12 +504,6 @@ public class HttpCreateDialog extends CommonDialog {
 			// ノード単位の重要度の定義
 	        m_numericValueInfo.setInputData(monitor);
 	    	
-	        // ジョブ実行
-	        m_checkJobRun.setSelection(YesNoConstant.typeToBoolean(monitor.getJobRun()));
-	        
-	        // 各重要度のジョブ実行
-	        m_jobRun.setInputData(monitor);
-	        m_jobRun.setEnabled(YesNoConstant.typeToBoolean(monitor.getJobRun()));
 		}
 		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
@@ -569,7 +526,7 @@ public class HttpCreateDialog extends CommonDialog {
     protected MonitorInfo createInputData() {
     	MonitorInfo info = new MonitorInfo();
 
-    	info.setMonitorTypeId(MonitorConstant.STRING_HTTP);
+    	info.setMonitorTypeId(HinemosModuleConstant.MONITOR_HTTP);
     	info.setMonitorType(m_monitorType);
     	
     	// 監視基本情報
@@ -583,13 +540,13 @@ public class HttpCreateDialog extends CommonDialog {
         if(validateResult != null){
         	return null;
         }
-
+        
         // 監視単位
-        info.setMonitorBlock(MonitorBlockConstant.TYPE_NODE);
+        info.setMonitorBlock(MonitorBlockConstant.TYPE_SCOPE);
         
         // 監視条件 HTTP監視情報
         MonitorHttpInfo httpInfo = new MonitorHttpInfo();
-        httpInfo.setMonitorTypeId(MonitorConstant.STRING_HTTP);
+        httpInfo.setMonitorTypeId(HinemosModuleConstant.MONITOR_HTTP);
         httpInfo.setMonitorId(info.getMonitorId());
         
         if (this.m_textRequestUrl.getText() != null
@@ -623,26 +580,21 @@ public class HttpCreateDialog extends CommonDialog {
         }        
         info.setCheckInfo((MonitorCheckInfo)httpInfo);
         
-        // 通知情報の属性
-        if (this.m_notifyInfo.getText() != null
-                && !"".equals((this.m_notifyInfo.getText()).trim())) {
-        	info.setNotifyId(m_notifyInfo.getText());
-        }
-//        else{
-//        	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.9"));
-//            return null;
-//        }
-        if (this.m_notifyInfo.getApplication() != null
-                && !"".equals((this.m_notifyInfo.getApplication()).trim())) {
-        	info.setApplication(m_notifyInfo.getApplication());
-        }
-        else{
-        	if (this.m_notifyInfo.getText() != null
-                    && !"".equals((this.m_notifyInfo.getText()).trim())) {
-            	this.setValidateResult(Messages.getString("message.hinemos.1"),Messages.getString("message.monitor.10"));
-                return null;
-            }
-        }
+        // 通知関連情報とアプリケーションの設定
+		// 通知グループIDの設定
+		info.setNotifyGroupId(NotifyRelationInfo.createNotifyGroupId(HinemosModuleConstant.MONITOR_HTTP, httpInfo.getMonitorId()));
+		validateResult = m_notifyInfo.createInputData(info);
+		if (validateResult != null) {
+			if(validateResult.getID() == null){	// 通知ID警告用出力
+				if(!displayQuestion(validateResult)){
+					validateResult = null;
+					return null;
+				}
+			}
+			else{	// アプリケーション未入力チェック
+				return null;
+			}
+		} 
         
         //　数値監視の場合     
 		if(m_monitorType == MonitorTypeConstant.TYPE_NUMERIC){
@@ -674,14 +626,6 @@ public class HttpCreateDialog extends CommonDialog {
                 return null;
             }
             
-	        // ジョブ実行
-	        info.setJobRun(YesNoConstant.booleanToType(m_checkJobRun.getSelection()));
-	        
-	        // 各重要度のジョブ実行
-	        validateResult = m_jobRun.createInputData(info);
-	        if(validateResult != null){
-	        	return null;
-	        }
 		}
 		// 文字列監視の場合
 		else if(m_monitorType == MonitorTypeConstant.TYPE_STRING){
@@ -700,9 +644,6 @@ public class HttpCreateDialog extends CommonDialog {
 	                return null;
 	            }
 	        }
-	        
-	        // ジョブ実行
-	        info.setJobRun(YesNoConstant.TYPE_YES);
 		}
         
         // 有効/無効
