@@ -318,7 +318,7 @@ public class JobEndInfoDAOImpl implements JobEndInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_end_info";
+			String sql = "SELECT session_id, job_id, end_status FROM cc_job_end_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -370,7 +370,7 @@ public class JobEndInfoDAOImpl implements JobEndInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_end_info WHERE session_id = ? AND job_id = ? AND end_status = ?";
+			String sql = "SELECT session_id, job_id, end_status FROM cc_job_end_info WHERE session_id = ? AND job_id = ? AND end_status = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -424,7 +424,7 @@ public class JobEndInfoDAOImpl implements JobEndInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_end_info WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id, end_status FROM cc_job_end_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
