@@ -346,7 +346,7 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_file_info";
+			String sql = "SELECT session_id, job_id FROM cc_job_file_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -397,7 +397,7 @@ public class JobFileInfoDAOImpl implements JobFileInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_file_info WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id FROM cc_job_file_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
