@@ -273,7 +273,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_start_job_info";
+			String sql = "SELECT session_id, job_id, target_job_id, target_job_type, target_job_end_value FROM cc_job_start_job_info";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			res = stmt.executeQuery();
@@ -327,7 +327,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 			conn = ConnectionManager.getConnectionManager().getConnection();
 			
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_start_job_info WHERE session_id = ? AND job_id = ? AND target_job_id = ? AND target_job_type = ? AND target_job_end_value = ?";
+			String sql = "SELECT session_id, job_id, target_job_id, target_job_type, target_job_end_value FROM cc_job_start_job_info WHERE session_id = ? AND job_id = ? AND target_job_id = ? AND target_job_type = ? AND target_job_end_value = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -383,7 +383,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_start_job_info WHERE session_id = ? AND target_job_id = ?";
+			String sql = "SELECT session_id, job_id, target_job_id, target_job_type, target_job_end_value FROM cc_job_start_job_info WHERE session_id = ? AND target_job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
@@ -442,7 +442,7 @@ public class JobStartJobInfoDAOImpl implements JobStartJobInfoDAO {
 		try {
 			conn = ConnectionManager.getConnectionManager().getConnection();	
 			//SQL文の定義
-			String sql = "SELECT * FROM cc_job_start_job_info WHERE session_id = ? AND job_id = ?";
+			String sql = "SELECT session_id, job_id, target_job_id, target_job_type, target_job_end_value FROM cc_job_start_job_info WHERE session_id = ? AND job_id = ?";
 			//SQL文のセット
 			stmt = conn.prepareStatement(sql);
 			
