@@ -40,6 +40,7 @@ import org.eclipse.swt.SWT;
 import org.quartz.SchedulerException;
 
 import com.clustercontrol.bean.CommonTableTreeItem;
+import com.clustercontrol.bean.OutputNotifyGroupInfo;
 import com.clustercontrol.bean.PluginConstant;
 import com.clustercontrol.bean.Property;
 import com.clustercontrol.bean.StatusConstant;
@@ -78,7 +79,6 @@ import com.clustercontrol.jobmanagement.factory.ModifySchedule;
 import com.clustercontrol.jobmanagement.factory.SelectJob;
 import com.clustercontrol.jobmanagement.factory.SelectRunSchedule;
 import com.clustercontrol.jobmanagement.factory.SelectSchedule;
-import com.clustercontrol.monitor.message.LogOutputInfo;
 import com.clustercontrol.util.Messages;
 import com.clustercontrol.util.apllog.AplLogger;
 
@@ -697,16 +697,16 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	    try {
             modify.registerJob(item, pri.getName());
         } catch (FinderException e) {
-            m_log.debug("registerJob() : " + e.getMessage());
+            m_log.debug("registerJob() : " + e.getMessage(),e);
             throw e;
         } catch (NamingException e) {
-            m_log.debug("registerJob() : " + e.getMessage());
+            m_log.debug("registerJob() : " + e.getMessage(),e);
             throw e;
         } catch (RemoveException e) {
-            m_log.debug("registerJob() : " + e.getMessage());
+            m_log.debug("registerJob() : " + e.getMessage(),e);
             throw e;
         } catch (CreateException e) {
-            m_log.debug("registerJob() : " + e.getMessage());
+            m_log.debug("registerJob() : " + e.getMessage(),e);
             throw e;
         }
 	}
@@ -776,7 +776,7 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	 * @throws FinderException
 	 * @throws NamingException
 	 * 
-	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#createJobInfo(String, LogOutputInfo)
+	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#createJobInfo(String, OutputNotifyGroupInfo)
 	 * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#runJob(String, String)
 	 */
 	public void runJob(String jobId, JobTriggerInfo triggerInfo) throws CreateException, FinderException, NamingException {
@@ -848,10 +848,10 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	 * @throws FinderException
 	 * @throws NamingException
 	 * 
-	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#createJobInfo(String, LogOutputInfo)
+	 * @see com.clustercontrol.jobmanagement.ejb.session.JobControllerBean#createJobInfo(String, OutputNotifyGroupInfo)
 	 * @see com.clustercontrol.jobmanagement.ejb.session.JobRunManagementBean#runJob(String, String)
 	 */
-	public void runJob(String jobId, LogOutputInfo info, JobTriggerInfo triggerInfo) throws CreateException, FinderException, NamingException {
+	public void runJob(String jobId, OutputNotifyGroupInfo info, JobTriggerInfo triggerInfo) throws CreateException, FinderException, NamingException {
 	    m_log.debug("runJob() : jobId=" + jobId);
 	    
 	    //ジョブ情報作成 新たなトランザクションを生成して実行するため、EJBメソッドで実行
@@ -973,10 +973,10 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	 * @throws FinderException
 	 * @throws NamingException
 	 * 
-	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionLocalHome#makeSession(java.lang.String, com.clustercontrol.monitor.message.LogOutputInfo)
-	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean#ejbHomeMakeSession(String, LogOutputInfo)
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionLocalHome#makeSession(java.lang.String, com.clustercontrol.notify.message.OutputNotifyGroupInfo)
+	 * @see com.clustercontrol.jobmanagement.ejb.entity.JobSessionBean#ejbHomeMakeSession(String, OutputNotifyGroupInfo)
 	 */
-	public String createJobInfo(String jobId, LogOutputInfo info, JobTriggerInfo triggerInfo) throws CreateException, FinderException, NamingException  {
+	public String createJobInfo(String jobId, OutputNotifyGroupInfo info, JobTriggerInfo triggerInfo) throws CreateException, FinderException, NamingException  {
 	    m_log.debug("createJobInfo() : jobId=" + jobId);
 
 	    try {
@@ -1595,10 +1595,11 @@ public abstract class JobControllerBean implements javax.ejb.SessionBean, CheckF
 	 * @return ジョブツリー情報{@link com.clustercontrol.jobmanagement.bean.JobTreeItem}
 	 * @throws NamingException
 	 * @throws FinderException
+	 * @throws CreateException 
 	 * 
 	 * @see com.clustercontrol.jobmanagement.factory.SelectJob#getSessionJobInfo(String, String)
 	 */
-	public JobTreeItem getSessionJobInfo(String sessionId, String jobId) throws NamingException, FinderException {
+	public JobTreeItem getSessionJobInfo(String sessionId, String jobId) throws NamingException, FinderException, CreateException {
 	    m_log.debug("getSessionJobInfo() : sessionId=" + sessionId + ", jobId=" + jobId);
 	    
 	    JobTreeItem item = null;
