@@ -22,7 +22,6 @@ import java.io.RandomAccessFile;
 import java.io.UnsupportedEncodingException;
 import java.nio.BufferUnderflowException;
 import java.nio.ByteBuffer;
-import java.util.Arrays;
 import java.util.Properties;
 
 import org.apache.commons.logging.Log;
@@ -42,11 +41,7 @@ import com.clustercontrol.util.Messages;
 public class TransferLogThread extends Thread {
 
 	private final static String UNCHANGED_STATS_PERIOD = "unchanged.stats.period";
-	
-	private final static String FIRST_PART_DATA_CHECK_PERIOD = "first.part.data.check.period";
 
-	private final static String FIRST_PART_DATA_CHECK_SIZE = "first.part.data.check.size";
-	
 	private final static String FILE_MAX_SIZE = "file.max.size";
 	
 	private final static String LOG_ENCODING = "log.file.encoding";
@@ -74,13 +69,7 @@ public class TransferLogThread extends Thread {
 
 	/** ファイル変更チェック期間設定（ミリ秒） */
 	protected int m_unchangedStatsPeriod = 0;
-	
-	/** ファイル変更詳細チェック（冒頭データ比較）期間（秒） */
-	protected int m_firstPartDataCheckPeriod = 0;
 
-	/** ファイル変更詳細チェック（冒頭データ比較）サイズ（byte） */
-	protected int m_firstPartDataCheckSize = 0;
-	
 	/** 上限ファイルサイズ設定（byte） */
 	protected long m_fileMaxSize = 0L;
 
@@ -113,7 +102,7 @@ public class TransferLogThread extends Thread {
 
 		m_transferLogManager = transferLogManager;
 		m_filePath = path;
-		m_runInterval = interval * 1000; // ミリ秒に変換 
+		m_runInterval = interval * 1000; // ミリ秒に変換
 		m_existenceFlg = flg;
 
 		// ファイル変更チェック期間（秒）
@@ -123,29 +112,7 @@ public class TransferLogThread extends Thread {
 		} catch (NumberFormatException e) {
 			log.error("TransferLogManager() : " + UNCHANGED_STATS_PERIOD, e);
 		}
-		log.debug(UNCHANGED_STATS_PERIOD + " = " + m_unchangedStatsPeriod);
 
-
-		// ファイル変更詳細チェック（冒頭データ比較）期間（秒）
-		String firstPartDataCheckPeriod = props.getProperty(FIRST_PART_DATA_CHECK_PERIOD, "300");
-		try {
-			this.m_firstPartDataCheckPeriod = Integer.parseInt(firstPartDataCheckPeriod) * 1000;
-		} catch (NumberFormatException e) {
-			log.error("TransferLogManager() : " + FIRST_PART_DATA_CHECK_PERIOD, e);
-		}
-		log.debug(FIRST_PART_DATA_CHECK_PERIOD + " = " + m_firstPartDataCheckPeriod);
-
-
-		// ファイル変更詳細チェック（冒頭データ比較）サイズ（byte）
-		String firstPartDataCheckSize = props.getProperty(FIRST_PART_DATA_CHECK_SIZE, "256");
-		try {
-			this.m_firstPartDataCheckSize = Integer.parseInt(firstPartDataCheckSize);
-		} catch (NumberFormatException e) {
-			log.error("TransferLogManager() : " + FIRST_PART_DATA_CHECK_SIZE, e);
-		}
-		log.debug(FIRST_PART_DATA_CHECK_SIZE + " = " + m_firstPartDataCheckSize);
-
-		
 		// 上限ファイルサイズ（byte）
 		String fileMaxSize = props.getProperty(FILE_MAX_SIZE, "2147483648");
 		try {
@@ -153,8 +120,6 @@ public class TransferLogThread extends Thread {
 		} catch (NumberFormatException e) {
 			log.error("TransferLogManager() : " + FILE_MAX_SIZE, e);
 		}
-		log.debug(FILE_MAX_SIZE + " = " + m_fileMaxSize);
-
 
 		// ログファイルのエンコーディングを設定
 		m_logEncoding =  props.getProperty(LOG_ENCODING);
@@ -163,7 +128,6 @@ public class TransferLogThread extends Thread {
 		if(m_logEncoding == null){
 			m_logEncoding = System.getProperty("file.encoding"); 
 		}
-		log.debug(LOG_ENCODING + " = " + m_logEncoding);
 		
 		m_syslog = new LoggerSyslog(props);
 	}
@@ -194,8 +158,6 @@ public class TransferLogThread extends Thread {
 
 		File name = new File(this.m_filePath); // 監視対象ログファイル
 
-		long lastDataCheck = System.currentTimeMillis(); // 最終詳細チェック（冒頭データ比較）実行時刻
-		
 		// ファイルオープン
 		RandomAccessFile fr = openFile(name, true, false);
 		if (fr == null) {
@@ -224,103 +186,10 @@ public class TransferLogThread extends Thread {
 
 					// ファイルサイズがm_unchangedStatsPeriod秒間以上変わらなかったら、ファイル切り替わりチェック
 					if ((++n_unchanged_stats * this.m_runInterval) >= this.m_unchangedStatsPeriod) {
-						log.debug("run() : " + m_filePath + " check log rotation");
-						boolean logrotate = false;
-						
+
 						// ログローテートされているかチェックする
-						// 従来の判定ロジック：
-						// 　現在監視しているファイルのサイズと本来監視すべきファイルのサイズが異なっている場合、
-						// 　mv方式によりローテートされたと判断する。
-						if (fr.length() != name.length()) { // ・・・（２）
-							log.debug("run() : " + m_filePath + " file size not match");
-							logrotate = true;
-						} else if (tmp_filesize > 0 && m_firstPartDataCheckPeriod > 0 &&
-								(System.currentTimeMillis() - lastDataCheck) > m_firstPartDataCheckPeriod){
-							log.debug("run() : " + m_filePath + " check first part of file");
-
-							// 追加された判定ロジック：
-							// 　現在監視しているファイルのサイズと本来監視すべきファイルのサイズが同じであっても、
-							// 　mv方式によりローテートされた可能性がある。
-							// 　ファイルの冒頭部分を確認することで、ローテートされたことを確認する。
-							byte[] refFirstPartOfFile = new byte[m_firstPartDataCheckSize];
-							Arrays.fill(refFirstPartOfFile, (byte)0);  // 全ての要素を0で初期化
-							byte[] newFirstPartOfFile = new byte[m_firstPartDataCheckSize];
-							Arrays.fill(newFirstPartOfFile, (byte)0);  // 全ての要素を0で初期化
-
-							// ファイル名指定で新たにオープンするファイル
-							RandomAccessFile newFile = null;
-							
-							// 現在監視しているファイルの冒頭データを取得
-							long bufSeek = 0;
-							try {
-								bufSeek = fr.getFilePointer();
-
-								// ファイル冒頭に移動する
-								fr.seek(0);
-								if (fr.read(refFirstPartOfFile) > 0) {
-									if(log.isDebugEnabled()){
-										try {
-											log.debug("run() : " + m_filePath + " refFirstPartOfFile : "
-													+ new String(refFirstPartOfFile, 
-															0, 
-															tmp_filesize < refFirstPartOfFile.length ? (int)tmp_filesize : refFirstPartOfFile.length, 
-																	m_logEncoding));
-										} catch (Exception e) {
-											log.error("run() : " + m_filePath + " " + e.getMessage(), e);
-										}
-									}
-									
-									// 再度ファイル名指定でファイルを開く
-									newFile = new RandomAccessFile(name, "r");
-									if (newFile.read(newFirstPartOfFile) > 0) {
-										if(log.isDebugEnabled()){
-											try {
-												log.debug("run() : " + m_filePath + " newFirstPartOfFile : "
-														+ new String(newFirstPartOfFile, 
-																0, 
-																tmp_filesize < newFirstPartOfFile.length ? (int)tmp_filesize : newFirstPartOfFile.length, 
-																		m_logEncoding));
-											} catch (Exception e) {
-												log.error("run() : " + m_filePath + " " + e.getMessage(), e);
-											}
-										}
-										
-										// ファイルの冒頭部分が異なれば別ファイルと判定
-										if (!Arrays.equals(refFirstPartOfFile, newFirstPartOfFile)) {
-											log.debug("run() : " + m_filePath + " log rotation detected");
-											logrotate = true;
-										}
-									}
-								}
-							} catch (Exception e) {
-								log.error("run() : " + m_filePath + " " + e.getMessage(), e);
-							} finally {
-								// ファイルのオフセットを元に戻す
-								if (bufSeek != 0) {
-									fr.seek(bufSeek);
-								}
-								
-								// オープンしたファイルをクローズ
-								if(newFile != null){
-									try {
-										newFile.close();
-									} catch (Exception e) {
-										log.error("run() : " + m_filePath + " " + e.getMessage(), e);
-									}
-								}
-							}
-							// 最終詳細チェック（ファイルデータ比較）実行時刻を設定
-							lastDataCheck = System.currentTimeMillis();
-						}
-
-						// ログローテートされたと判定された場合
-						if(logrotate){
-							// 再度ファイルサイズの増加を確認する
-							// ローテートされたと判定されたが、実は、ローテートされておらず、
-							//  （１）の時点では最終ログ読み込み時からログが出力されていないためサイズ（filesize）は同一であったが、
-							//  （２）の判定直前にログが出力された場合は、ローテートされたと誤検知するため、
-							// 再度サイズ比較を行う。
-							if (tmp_filesize == fr.length()) {
+						if (fr.length() != name.length()) { // 現在監視しているファイルのサイズと本来監視すべきファイルのサイズが異なっている
+							if (tmp_filesize == fr.length()) { // 現在監視しているファイルのサイズが（１）で取得した値と同じである
 								log.info(this.m_filePath + ":ファイルが切替りました");
 								closeFile(fr);
 
@@ -475,9 +344,6 @@ public class TransferLogThread extends Thread {
 					// }
 
 					filesize = tmp_filesize;
-					if(log.isDebugEnabled()){
-						log.debug("run() : " + m_filePath + " filesize = " + filesize + ", FilePointer = " + fr.getFilePointer());
-					}
 
 				} else if (filesize > tmp_filesize) {
 					// 切詰
