@@ -591,7 +591,6 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 	 * @throws NamingException 
 	 * @throws FinderException 
 	 * @throws SQLException
-	 * @throws RemoveException 
 	 * 
 	 * @ejb.interface-method
 	 * 
@@ -600,10 +599,12 @@ public abstract class MaintenanceControllerBean implements SessionBean {
      *     method-intf="Remote"
      *     
 	 */
-	public int deleteJobHistory(String keep_id) throws FinderException, NamingException, CreateException, SQLException, RemoveException {
+	public int deleteJobHistory(String keep_id) throws FinderException, NamingException, CreateException, SQLException {
 		m_log.debug("deleteJobHistory()");
 		
-		int ret = 0;
+		int ret = 0;	// target job_session_id count
+		int ret1 = 0;	// target notify_relation_info count
+		int ret2 = 0;	// target action_inhibition_inf count
 		Connection conn = null;
 		Statement stmt = null;
 		
@@ -615,117 +616,66 @@ public abstract class MaintenanceControllerBean implements SessionBean {
 			//SQL文のセット
 			stmt = conn.createStatement();
 			
-			// 削除対象となるsession_idを検索する副問い合わせをもつwhere句
-			String select_sessionId = "SELECT session_id from cc_job_session_job where (status='300' OR status='301') and end_date < '" + timestamp.toString() + "'";
+			///////////////////////////////////////////////
+			// SET SQL STATEMENT
+			///////////////////////////////////////////////
+
+			// 削除対象となるsession_idを格納するテンポラリテーブル作成(スキーマ定義引継ぎ)
+			String create_sessionId_table = "CREATE TABLE cc_job_completed_sessions AS SELECT session_id FROM cc_job_session LIMIT 0";
+			// 削除対象となるsession_idを格納するテンポラリテーブル削除
+			String drop_sessionId_table = "DROP TABLE cc_job_completed_sessions";
 			
-			// cc_job_session テーブルの情報を削除する際に利用する、削除対象となるsession_idのリスト
-			String sql_select_list = "select session_id, job_id from cc_job_session_job WHERE session_id IN (" + select_sessionId + ");";
+			// 削除対象となるsession_idの検索と挿入
+			String insert_select_sessionId = 
+				"INSERT INTO cc_job_completed_sessions " +
+					"SELECT session_id FROM cc_job_session_job " +
+						"WHERE (status='300' OR status='301') AND " +
+						"end_date < '" + timestamp.toString() + "' AND " + 
+						"(job_id, session_id ) IN (SELECT job_id,session_id FROM cc_job_session)";
 			
-			ResultSet res = stmt.executeQuery(sql_select_list);
-			ArrayList<String> notifyGroupIdList = new ArrayList<String>();
+			// 削除:cc_job_sessionと関連テーブル(CASCADE)
+			String detete_job_session = "DELETE FROM cc_job_session WHERE session_id IN (SELECT session_id FROM cc_job_completed_sessions)";
+			// 削除:cc_notify_relation_info
+			String detete_notify_relation_info = "DELETE FROM cc_notify_relation_info WHERE ( notify_group_id ) LIKE ANY (SELECT DISTINCT 'JOB_SES-' || session_id || '%' FROM cc_job_completed_sessions)";
+			// 削除:cc_action_inhibition_info
+			String detete_action_inhibition_info = "DELETE FROM cc_action_inhibition_info WHERE ( notify_group_id ) LIKE ANY (SELECT DISTINCT 'JOB_SES-' || session_id || '%' FROM cc_job_completed_sessions)";
 			
-			// 削除対象となるセッションIDのセット
-			HashSet<String> sessionIds = new HashSet<String>();
+			///////////////////////////////////////////////
+			// RUN SQL STATEMENT
+			///////////////////////////////////////////////
+			m_log.debug("deleteJobHistory() : CREATE TEMPORARY TABLE AND INSERT JOB_SESSION_ID");
+			stmt.execute(create_sessionId_table);
+			stmt.execute(insert_select_sessionId);
 			
-			while(res.next()){
-				sessionIds.add(res.getString(1));
-				
-				//　削除する通知グループIDの取得
-				notifyGroupIdList.add(
-						NotifyRelationInfo.createNotifyGroupIdJobInfo(res.getString(1), res.getString(2), 0)
-						);
-			}
+			m_log.debug("deleteJobHistory() : DROP cc_job_session");
+			ret = stmt.executeUpdate(detete_job_session);
+			m_log.debug("deleteJobHistory() : DROP cc_job_session COUNT = " + ret);
 			
 			
-			if (sessionIds.size() == 0) {
-				ret = 0;
-				
-			} else {
-				
-				m_log.debug("delete start");
-				m_log.debug("DELETE FROM cc_job_session WHERE session_id IN (" + select_sessionId + ");");
-				
-				ret = stmt.executeUpdate("DELETE FROM cc_job_session WHERE session_id IN (" + select_sessionId + ");");
-				
-//				stmt.executeUpdate("DELETE FROM cc_job_param_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_end_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_notice_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_command_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_start_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_start_job_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_start_time_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_file_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_relation_info WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_session_node WHERE session_id IN (" + select_sessionId + ");");
-//				stmt.executeUpdate("DELETE FROM cc_job_session_job WHERE session_id IN (" + select_sessionId + ");");
-//				
-//				// cc_job_session テーブルの内容を削除する際には、cc_job_session_jobテーブルが削除されているので、
-//				// あらかじめ作成しておいたsession_idのリストを使用する
-//				
-//				// session_idのリストが長すぎるとエラーとなるため、プロパティで設定した数だけ繰り返し消す
-//				int bufsize = MaintenanceProperties.getInstance().getDeleteBufSize();
-//				m_log.debug("bufsize : " + bufsize);
-//				StringBuffer stb = new StringBuffer();
-//				
-//				Iterator<String> ite = sessionIds.iterator();
-//				while (ite.hasNext()){
-//					
-//					//指定されたバッファサイズ分だけ、session_idを取り出す
-//					for (int i = 0; i < bufsize; i++) {
-//						if (ite.hasNext()){
-//							stb.append("'");
-//							stb.append(ite.next());
-//							stb.append("'");
-//							stb.append(",");
-//						}
-//					}
-//					
-//					// 余分に付いているカンマを削除
-//					stb.delete(stb.length() - 1, stb.length());
-//					
-//					String sql = "DELETE FROM cc_job_session WHERE session_id IN (" + stb.toString() + ");";
-//					m_log.debug("delete cc_job_session : " + sql);
-//					
-//					//cc_job_sessionの削除件数を返り値とする
-//					int updateResult = stmt.executeUpdate(sql);
-//					m_log.debug("delete : " + updateResult);
-//					
-//					ret = ret + updateResult;
-//					
-//					stb.delete(0, stb.length());
-//				}
-//				
-			}
-			m_log.debug("delete count : " + ret);
+			m_log.debug("deleteJobHistory() : DROP cc_notify_relation_info");
+			ret1 = stmt.executeUpdate(detete_notify_relation_info);
+			m_log.debug("deleteJobHistory() : DROP cc_notify_relation_info COUNT = " + ret1);
 			
 			
-			// 通知連携と抑制の削除
-			NotifyControllerLocal notifyController = NotifyControllerUtil.getLocalHome().create();		
-			Iterator<String> itr = notifyGroupIdList.iterator();
-			String deleteNotifyGroupId = null;
-			while(itr.hasNext()) {
-				deleteNotifyGroupId = itr.next();
-				notifyController.deleteNotifyRelation(deleteNotifyGroupId);
-				notifyController.deleteNotifyInhibition(deleteNotifyGroupId);
-			}
+			m_log.debug("deleteJobHistory() : DROP cc_action_inhibition_info");
+			ret2 = stmt.executeUpdate(detete_action_inhibition_info);
+			m_log.debug("deleteJobHistory() : DROP cc_action_inhibition_info COUNT = " + ret2);
+			
+			m_log.debug("deleteJobHistory() : DROP TEMPORARY TABLE");
+			stmt.execute(drop_sessionId_table);
+			
 			
 			return ret;
 			
 		} catch (SQLException e) {
 			m_log.error("removeAll() error : SQLException " + e.getMessage());
 			throw e;
-//			e.printStackTrace();
-
-		} catch (RemoveException e) {
-			m_log.error("removeAll() error : RemoveException " + e.getMessage());
-			throw e;
 		} finally {
 			try {
 				stmt.close();
 				conn.close();
 			} catch (SQLException e) {
-				
+				throw e;				
 			}
 		}
 	}
