@@ -40,18 +40,14 @@ import com.clustercontrol.notify.ejb.entity.NotifyActionInhibitionInfoData;
 import com.clustercontrol.notify.factory.AddNotify;
 import com.clustercontrol.notify.factory.AddNotifyInhibition;
 import com.clustercontrol.notify.factory.AddNotifyRelation;
-import com.clustercontrol.notify.factory.AddSystemNotify;
 import com.clustercontrol.notify.factory.DeleteNotify;
 import com.clustercontrol.notify.factory.DeleteNotifyInhibition;
 import com.clustercontrol.notify.factory.DeleteNotifyRelation;
-import com.clustercontrol.notify.factory.DeleteSystemNotify;
 import com.clustercontrol.notify.factory.ModifyNotify;
 import com.clustercontrol.notify.factory.ModifyNotifyInhibition;
 import com.clustercontrol.notify.factory.ModifyNotifyRelation;
-import com.clustercontrol.notify.factory.ModifySystemNotify;
 import com.clustercontrol.notify.factory.SelectNotify;
 import com.clustercontrol.notify.factory.SelectNotifyRelation;
-import com.clustercontrol.notify.factory.SelectSystemNotify;
 import com.clustercontrol.util.Messages;
 
 /**
@@ -253,7 +249,7 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 		
 		return list;
 	}
-	
+		
 	/**
 	 * 通知情報マップを返します。
 	 * 
@@ -281,6 +277,61 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 		return map;
 	}
 	
+	/**
+	 * 障害検知用通知情報一覧を返します。
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+	 *     role-name="NotifyRead"
+	 *     method-intf="Remote"
+	 * 
+	 * @jboss.method-attributes
+	 *     read-only="true"
+	 * 
+	 * @return 通知情報一覧（Objectの2次元配列）
+	 * @throws CreateException
+	 * @throws FinderException
+	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.notify.factory.SelectNotify#getNotifyList()
+	 */
+	public ArrayList getTroubleDetectionNotifyList() throws CreateException, FinderException, NamingException {
+		
+		// 通知一覧を取得
+		SelectNotify notify = new SelectNotify();
+		ArrayList list = notify.getTroubleDetectionNotifyList();
+		
+		return list;
+	}
+	
+	/**
+	 * 障害検知用通知情報マップを返します。
+	 * 
+	 * @ejb.interface-method
+	 * 
+	 * @ejb.permission
+	 *     role-name="NotifyRead"
+	 *     method-intf="Remote"
+	 * 
+	 * @jboss.method-attributes
+	 *     read-only="true"
+	 * 
+	 * @return 通知情報マップ
+	 * @throws FinderException
+	 * @throws NamingException
+	 * 
+	 * @see com.clustercontrol.notify.factory.SelectNotify#getNotifyMap()
+	 */
+	public HashMap<String, NotifyInfo> getTroubleDetectionNotifyMap() throws FinderException, NamingException {
+		
+		// 通知一覧を取得
+		SelectNotify notify = new SelectNotify();
+		HashMap<String, NotifyInfo> map = notify.getTroubleDetectionNotifyMap();
+		
+		return map;
+	}
+	
 	/**
 	 * 通知情報一覧のテーブル定義情報を返します。<BR>
 	 * リストに、カラム毎にテーブルカラム情報をセットします。
@@ -319,109 +370,109 @@ public abstract class NotifyControllerBean implements javax.ejb.SessionBean {
 		return tableDefine;
 	}
 	
-	/**
-	 * システム通知情報を作成します。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @ejb.permission
-	 *     role-name="NotifyWrite"
-	 *     method-intf="Remote"
-	 * 
-	 * @param info 作成対象のシステム通知情報
-	 * @return 作成に成功した場合、<code> true </code>
-	 * @throws CreateException
-	 * @throws NamingException
-	 * @throws JMSException
-	 * 
-	 * @see com.clustercontrol.notify.factory.AddSystemNotify#add(NotifyInfo)
-	 */
-	public boolean addSystemNotify(NotifyInfo info) throws CreateException, NamingException, JMSException {
-		
-		// システム通知情報を登録
-		AddSystemNotify notify = new AddSystemNotify();
-		return  notify.add(info);
-	}
-	
-	/**
-	 * システム通知情報を変更します。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @ejb.permission
-	 *     role-name="NotifyWrite"
-	 *     method-intf="Remote"
-	 * 
-	 * @param info 変更対象のシステム通知情報
-	 * @return 変更に成功した場合、<code> true </code>
-	 * @throws CreateException
-	 * @throws FinderException
-	 * @throws RemoveException
-	 * @throws NamingException
-	 * @throws JMSException
-	 * 
-	 * @see com.clustercontrol.notify.factory.ModifySystemNotify#modify(NotifyInfo)
-	 */
-	public boolean modifySystemNotify(NotifyInfo info) throws CreateException, FinderException, RemoveException, NamingException, JMSException {
-		
-		// システム通知情報を更新
-		ModifySystemNotify notify = new ModifySystemNotify();
-		return  notify.modify(info);
-	}
-	
-	/**
-	 * システム通知情報を削除します。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @ejb.permission
-	 *     role-name="NotifyWrite"
-	 *     method-intf="Remote"
-	 * 
-	 * @param notifyId 削除対象の通知ID
-	 * @return 削除に成功した場合、<code> true </code>
-	 * @throws FinderException
-	 * @throws RemoveException
-	 * @throws NamingException
-	 * @throws JMSException
-	 * 
-	 * @see com.clustercontrol.notify.factory.DeleteSystemNotify#delete(String)
-	 */
-	public boolean deleteSystemNotify(String notifyId) throws FinderException, RemoveException, NamingException, JMSException {
-		
-		// システム通知情報を削除
-		DeleteSystemNotify notify = new DeleteSystemNotify();
-		return  notify.delete(notifyId);
-	}
-	
-	/**
-	 * 引数で指定されたシステム通知情報を返します。
-	 * 
-	 * @ejb.interface-method
-	 * 
-	 * @ejb.permission
-	 *     role-name="NotifyRead"
-	 *     method-intf="Remote"
-	 * 
-	 * @jboss.method-attributes
-	 *     read-only="true"
-	 * 
-	 * @param notifyId 取得対象の通知ID
-	 * @return システム通知情報
-	 * @throws CreateException
-	 * @throws FinderException
-	 * @throws NamingException
-	 * 
-	 * @see com.clustercontrol.notify.factory.SelectSystemNotify#getNotify(String)
-	 */
-	public NotifyInfo getSystemNotify(String notifyId) throws FinderException, NamingException {
-		
-		// システム通知情報を取得
-		SelectSystemNotify notify = new SelectSystemNotify();
-		NotifyInfo info = notify.getNotify(notifyId);
-		
-		return info;
-	}
+//	/**
+//	 * システム通知情報を作成します。
+//	 * 
+//	 * @ejb.interface-method
+//	 * 
+//	 * @ejb.permission
+//	 *     role-name="NotifyWrite"
+//	 *     method-intf="Remote"
+//	 * 
+//	 * @param info 作成対象のシステム通知情報
+//	 * @return 作成に成功した場合、<code> true </code>
+//	 * @throws CreateException
+//	 * @throws NamingException
+//	 * @throws JMSException
+//	 * 
+//	 * @see com.clustercontrol.notify.factory.AddSystemNotify#add(NotifyInfo)
+//	 */
+//	public boolean addSystemNotify(NotifyInfo info) throws CreateException, NamingException, JMSException {
+//		
+//		// システム通知情報を登録
+//		AddSystemNotify notify = new AddSystemNotify();
+//		return  notify.add(info);
+//	}
+//	
+//	/**
+//	 * システム通知情報を変更します。
+//	 * 
+//	 * @ejb.interface-method
+//	 * 
+//	 * @ejb.permission
+//	 *     role-name="NotifyWrite"
+//	 *     method-intf="Remote"
+//	 * 
+//	 * @param info 変更対象のシステム通知情報
+//	 * @return 変更に成功した場合、<code> true </code>
+//	 * @throws CreateException
+//	 * @throws FinderException
+//	 * @throws RemoveException
+//	 * @throws NamingException
+//	 * @throws JMSException
+//	 * 
+//	 * @see com.clustercontrol.notify.factory.ModifySystemNotify#modify(NotifyInfo)
+//	 */
+//	public boolean modifySystemNotify(NotifyInfo info) throws CreateException, FinderException, RemoveException, NamingException, JMSException {
+//		
+//		// システム通知情報を更新
+//		ModifySystemNotify notify = new ModifySystemNotify();
+//		return  notify.modify(info);
+//	}
+//	
+//	/**
+//	 * システム通知情報を削除します。
+//	 * 
+//	 * @ejb.interface-method
+//	 * 
+//	 * @ejb.permission
+//	 *     role-name="NotifyWrite"
+//	 *     method-intf="Remote"
+//	 * 
+//	 * @param notifyId 削除対象の通知ID
+//	 * @return 削除に成功した場合、<code> true </code>
+//	 * @throws FinderException
+//	 * @throws RemoveException
+//	 * @throws NamingException
+//	 * @throws JMSException
+//	 * 
+//	 * @see com.clustercontrol.notify.factory.DeleteSystemNotify#delete(String)
+//	 */
+//	public boolean deleteSystemNotify(String notifyId) throws FinderException, RemoveException, NamingException, JMSException {
+//		
+//		// システム通知情報を削除
+//		DeleteSystemNotify notify = new DeleteSystemNotify();
+//		return  notify.delete(notifyId);
+//	}
+//	
+//	/**
+//	 * 引数で指定されたシステム通知情報を返します。
+//	 * 
+//	 * @ejb.interface-method
+//	 * 
+//	 * @ejb.permission
+//	 *     role-name="NotifyRead"
+//	 *     method-intf="Remote"
+//	 * 
+//	 * @jboss.method-attributes
+//	 *     read-only="true"
+//	 * 
+//	 * @param notifyId 取得対象の通知ID
+//	 * @return システム通知情報
+//	 * @throws CreateException
+//	 * @throws FinderException
+//	 * @throws NamingException
+//	 * 
+//	 * @see com.clustercontrol.notify.factory.SelectSystemNotify#getNotify(String)
+//	 */
+//	public NotifyInfo getSystemNotify(String notifyId) throws FinderException, NamingException {
+//		
+//		// システム通知情報を取得
+//		SelectSystemNotify notify = new SelectSystemNotify();
+//		NotifyInfo info = notify.getNotify(notifyId);
+//		
+//		return info;
+//	}
 	
 	
 	/**
