@@ -259,7 +259,9 @@ public class SelectNotify {
 	 */
 	public ArrayList getNotifyIdList() throws FinderException, NamingException {
 
-		ArrayList<String> list = null;
+		// 戻り値の初期化
+		ArrayList<String> list = new ArrayList<String>();
+		
 		try 
 		{
 			// 通知情報一覧を取得
@@ -268,10 +270,6 @@ public class SelectNotify {
 			Iterator itr = ct.iterator();
 			while(itr.hasNext())
 			{
-				if(list == null){
-					list = new ArrayList<String>();
-				}
-				
 				NotifyInfoLocal notify = (NotifyInfoLocal)itr.next();
 				list.add(notify.getNotifyId());
 			}
