@@ -158,17 +158,16 @@ public class CollectorTreeComposite extends Composite {
 					// 項目がカテゴリではない場合
 					if(treeItem.isCategoryItem() == false){					
 						
-						String deviceName = "";
+						String displayName = "";
 						
 						if(treeItem.getDeviceData() != null){
-							deviceName = treeItem.getDeviceData().getDeviceName();
+							displayName = treeItem.getDeviceData().getDisplayName();
 						}
 						
 						CollectorItemInfo itemInfo = new CollectorItemInfo(
 								m_collectorID,  // 収集ID
-								treeItem.getCollectMethod(),	// 収集方法
 								treeItem.getItemCode(),  // 収集項目コード
-								deviceName  // デバイス名
+								displayName  // リポジトリ表示名
 						);
 						
 						this.itemList.add(itemInfo);
@@ -234,8 +233,8 @@ public class CollectorTreeComposite extends Composite {
 							if(deviceData == null){
 								treeItems[i].setChecked(true);
 								checked = true;
-							} else {	// デバイス単位の項目の場合はデバイス名まで一致した場合チェックを入れる
-								if(deviceData.getDeviceName().equals(itemInfo.getDeviceName())){
+							} else {	// デバイス単位の項目の場合はリポジトリ表示名まで一致した場合チェックを入れる
+								if(deviceData.getDisplayName().equals(itemInfo.getDisplayName())){
 									treeItems[i].setChecked(true);
 									checked = true;
 								}
