@@ -157,7 +157,7 @@ public class CollectorItemComboComposite extends Composite {
     		CollectorItemInfo itemInfo = itr.next();
     		
     		if(itemInfo.getItemCode().equals(perfCheckInfo.getItemCode()) &&
-    				itemInfo.getDeviceName().equals(perfCheckInfo.getDeviceName())){
+    				itemInfo.getDisplayName().equals(perfCheckInfo.getDisplayName())){
     			index = i;
     		}
     		i++;
@@ -204,11 +204,19 @@ public class CollectorItemComboComposite extends Composite {
 //					e.printStackTrace();
 //				}
 //	            perfCheckInfo.setDeviceIndex(itemInfo.getDeviceIndex());
-	            if(itemInfo.getDeviceName() != null){
-	            	perfCheckInfo.setDeviceName(itemInfo.getDeviceName());
+//	            if(itemInfo.getDeviceName() != null){
+//	            	perfCheckInfo.setDeviceName(itemInfo.getDeviceName());
+//	            }
+//	            else {
+//	            	perfCheckInfo.setDeviceName("");
+//	            }
+	            perfCheckInfo.setDeviceName("");
+                
+	            if(itemInfo.getDisplayName() != null){
+	            	perfCheckInfo.setDisplayName(itemInfo.getDisplayName());
 	            }
 	            else {
-	            	perfCheckInfo.setDeviceName("");
+	            	perfCheckInfo.setDisplayName("");
 	            }
 	            
 	            info.setCheckInfo(perfCheckInfo);
