@@ -60,8 +60,12 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
         //			NonDisplay:非表示
         //				暫定仕様。ダイアログ画面でデータ項目が固定のバージョン用。
         //				将来はデータ項目を選択可能にすることを視野にいれる。
-        itemInfo = new String[graphNum][5];
-        itemInfoForDialog = new String[graphNum][5];
+        
+        // 下記の4について、
+        // itemCode, displayType, displayName, displayFormの4つ。
+        // 配列にするのは激しく微妙…。
+        itemInfo = new String[graphNum][4];
+        itemInfoForDialog = new String[graphNum][4];
 
       itemInfoBoolean = new boolean[graphNum][1];
       itemInfoForDialogBoolean = new boolean[graphNum][1];
@@ -82,13 +86,15 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
      * @param i
      * @param itemCode
      * @param displayType
-     * @param deviceName
+     * @param displayName
      * @param isDetailed
      */
-    public void setItemInfo(int i, String itemCode, String displayType, String deviceName, boolean isDetailed) {
+    public void setItemInfo(int i, String itemCode, String displayType, String displayName,
+    		 String displayForm, boolean isDetailed) {
     	itemInfo[i][0] = itemCode;
     	itemInfo[i][1] = displayType;
-    	itemInfo[i][2] = deviceName;
+    	itemInfo[i][2] = displayName;
+    	itemInfo[i][3] = displayForm;
     	itemInfoBoolean[i][0] = isDetailed;
     }
     
@@ -111,25 +117,31 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
     }
     
     /**
-     * デバイス名を取得します。
+     * リポジトリ表示名を取得します。
      * @param i
      * @return
      */
-    public String getDeviceName(int i) {
+    public String getDisplayName(int i) {
     	return (itemInfo[i][2]) ;
     }
     
     /**
-     * デバイス名を設定します。
+     * グラフの形を取得します。
      * @param i
-     * @param deviceName
+     * @return
      */
-    public void setDeviceName(int i, String deviceName) {
-    	itemInfo[i][2] = deviceName;
+    public String getDisplayForm(int i) {
+    	return (itemInfo[i][3]) ;
     }
     
-    
-    
+    /**
+     * リポジトリ表示名を設定します。
+     * @param i
+     * @param displayName
+     */
+    public void setDisplayName(int i, String displayName) {
+    	itemInfo[i][2] = displayName;
+    }
     /**
      * 詳細か否かを設定します。
      * @param i
@@ -189,13 +201,16 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
      * @param i
      * @param itemCode
      * @param displayType
-     * @param deviceName
+     * @param displayName
+     * @param displayForm
      * @param isDetailed
      */
-    public void setItemInfoForDialog(int i, String itemCode, String displayType, String deviceName, boolean isDetailed) {
+    public void setItemInfoForDialog(int i, String itemCode, String displayType, String displayName,
+    		String displayForm, boolean isDetailed) {
     	itemInfoForDialog[i][0] = itemCode;
     	itemInfoForDialog[i][1] = displayType;
-    	itemInfoForDialog[i][2] = deviceName;
+    	itemInfoForDialog[i][2] = displayName;
+    	itemInfoForDialog[i][3] = displayForm;
     	itemInfoForDialogBoolean[i][0] = isDetailed;
     }
     
@@ -218,14 +233,23 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
     }
     
     /**
-     * デバイス名を取得します。
+     * リポジトリ表示名を取得します。
      * @param i
-     * @return デバイス名
+     * @return リポジトリ表示名
      */
-    public String getDeviceNameForDialog(int i) {
+    public String getDisplayNameForDialog(int i) {
     	return (itemInfoForDialog[i][2]) ;
     }
     
+    /**
+     * グラフの形を取得します。
+     * @param i
+     * @return 表示種別
+     */
+    public String getDisplayFormForDialog(int i) {
+    	return (itemInfoForDialog[i][3]) ;
+    }
+    
     public void isItemDetailedForDialog(int i, boolean isDetailed) {
     	this.itemInfoForDialogBoolean[i][0] = isDetailed;
     }
@@ -249,12 +273,21 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
     }
     
     /**
-     * デバイス名を設定します。
+     * リポジトリ表示名を設定します。
      * @param i
-     * @param deviceName デバイス名
+     * @param displayName リポジトリ表示名
      */
-    public void setDeviceNameForDialog(int i, String deviceName) {
-    	itemInfoForDialog[i][2] = deviceName;
+    public void setDisplayNameForDialog(int i, String displayName) {
+    	itemInfoForDialog[i][2] = displayName;
+    }
+    
+    /**
+     * グラフの形を設定します。
+     * @param i
+     * @param displayForm
+     */
+    public void setDisplayFormForDialog(int i, String displayForm) {
+    	itemInfoForDialog[i][3] = displayForm;
     }
     
     /**
@@ -266,6 +299,7 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
     				itemInfo[i][0],
     				itemInfo[i][1],
     				itemInfo[i][2],
+    				itemInfo[i][3],
     				itemInfoBoolean[i][0]);
     	}
     }
@@ -278,6 +312,7 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
     				itemInfoForDialog[i][0],
     				itemInfoForDialog[i][1],
     				itemInfoForDialog[i][2],
+    				itemInfoForDialog[i][3],
     				itemInfoForDialogBoolean[i][0]);
     	}
     }
@@ -292,11 +327,11 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
     }
     
     /**
-     * デバイス名を取得します。
+     * リポジトリ表示名を取得します。
      * @param i
-     * @return デバイス名
+     * @return リポジトリ表示名
      */
-    public String getDeviceNameForCollector(int i) {
+    public String getDisplayNameForCollector(int i) {
     	return (itemInfoForCollector[i][1]) ;
     }
     
@@ -305,13 +340,13 @@ public class RealtimeCollectorItemInfo extends RealtimeCollectorInfo {
      * @param i
      * @param itemCode 収集項目コード
      * @param deviceIndex デバイスインデックス
-     * @param deviceName デバイス名
+     * @param displayName リポジトリ表示名
      * @param isDetailed 詳細か否かのフラグ
      */
-    public void setItemInfoForCollector(int i, String itemCode, String deviceName, boolean isDetailed) {
+    public void setItemInfoForCollector(int i, String itemCode, String displayName, boolean isDetailed) {
     	this.itemInfoForCollector[i][0] = itemCode;
-    	if (deviceName != null && ! deviceName.equals("Non")) {
-    		this.itemInfoForCollector[i][1] = deviceName;
+    	if (displayName != null && ! displayName.equals("Non")) {
+    		this.itemInfoForCollector[i][1] = displayName;
     	}
     	else {
     		this.itemInfoForCollector[i][1] = "";
