@@ -72,7 +72,8 @@ public class RealtimeGraphView extends ScopeListBaseView {
 	 *  リアルタイムグラフを描画します。
 	 */
 	public RealtimeGraphView() {
-		super();
+		// ノードを含め、INTERNAL, UNREGISTEREDを含めず, TOPICを受信するスコープツリーとする 
+		super(false, false, false, true);
 		initialize();
 	}
 
