@@ -18,7 +18,7 @@ package com.clustercontrol.performance.operator;
 /**
  * 何も加工しない値を返します。
  */
-public class Non extends SnmpOperator {
+public class Non extends Operator {
 	@Override
 	public double calc() throws CollectedDataNotFoundException, InvalidValueException{
 		return getCurrentMibValue("var0");			
