@@ -20,6 +20,8 @@ import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.util.ArrayList;
+import java.util.HashSet;
+import java.util.Iterator;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
@@ -83,7 +85,7 @@ public class ReachAddressFping {
 	 * @param info
 	 * @return PING監視ステータス
 	 */
-	public boolean isReachable(ArrayList hosts, int version) {
+	public boolean isReachable(HashSet<String> hosts, int version) {
 		
 		
 		Process process = null ;//fpingプロセス
@@ -105,10 +107,15 @@ public class ReachAddressFping {
 		cmd[4] = "-q" ; 
 		
 		//コマンドを実行するために値を詰め替えます。
-		for(int i = 0 ; i < hosts.size(); i++ ){
-			cmd[i+5]=(String)hosts.get(i);
+		Iterator<String> itr = hosts.iterator();
+		int i = 0;
+		while(itr.hasNext()) {
+			cmd[i + 5] = itr.next();
+			i++;
 		}
-		
+//		for(int i = 0 ; i < hosts.size(); i++ ){
+//			cmd[i+5]=(String)hosts.get(i);
+//		}
 		
 		try {      	
 			process = Runtime.getRuntime().exec(cmd); 	
