@@ -1088,8 +1088,8 @@ public class NodeProperty {
 		
 		virtNodeType.setValue("");
 		Object vmNodeTypeValue[][] = {
-				{ "", "host", "guest" },
-				{ "", "host", "guest" }
+				{ "", "controller", "host", "guest" },
+				{ "", "controller", "host", "guest" }
 		};
 		
 		virtualization.setValue("");
@@ -1495,7 +1495,7 @@ public class NodeProperty {
 	 * DisplayText	：　ファシリティ名(ファシリティID)
 	 * 
 	 * 値をセットするメソッドの引数がObject型の２次元配列のため、その形式で返す.
-	 * 対象は管理ノード=Hostノード+UNALLOCATED
+	 * 対象は管理ノード=Hostノード + Controllerノード + UNALLOCATED
 	 * 
 	 * @return オブジェクト配列
 	 * @throws FinderException
@@ -1507,22 +1507,34 @@ public class NodeProperty {
 		
 		try{
 			HashMap<String, String> condition = new HashMap<String, String>();
-			condition.put(FacilityAttributeConstant.VIRTNODETYPE, "host");
-			Collection nodes = FacilityUtil.getLocalHome().findByCondition(condition);
-			Iterator iterator = nodes.iterator();
-			ArrayList<String> facilityIdList = new ArrayList();
-			ArrayList<String> facilityNameList = new ArrayList();
+			ArrayList<String> facilityIdList = new ArrayList<String>();
+			ArrayList<String> facilityNameList = new ArrayList<String>();
+			Collection<FacilityLocal> nodes = null;
 			facilityIdList.add("");
 			facilityNameList.add("");
-			while (iterator.hasNext()) {
-				FacilityLocal facility = (FacilityLocal)iterator.next();
+			
+			// ノード種別がhostであるノードをリストに追加。
+			condition.put(FacilityAttributeConstant.VIRTNODETYPE, "host");
+			nodes = FacilityUtil.getLocalHome().findByCondition(condition);
+			for (FacilityLocal facility : nodes) {
 				facilityIdList.add(facility.getFacilityId());
 				facilityNameList.add(facility.getCn() + "(" + facility.getFacilityId() + ")" );
 			}
-			//未割当を選択できるようにUNALLOCATEDを追加
+			
+			// ノード種別がcontrollerであるノードをリストに追加。
+			condition.clear();
+			condition.put(FacilityAttributeConstant.VIRTNODETYPE, "controller");
+			nodes = FacilityUtil.getLocalHome().findByCondition(condition);
+			for (FacilityLocal facility : nodes) {
+				facilityIdList.add(facility.getFacilityId());
+				facilityNameList.add(facility.getCn() + "(" + facility.getFacilityId() + ")" );
+			}
+			
+			// 未割当を選択できるようにUNALLOCATEDを追加
 			facilityIdList.add(FacilityTreeAttributeConstant.UNALLOCATED_SCOPE);
 			facilityNameList.add(Messages.getString("vm.scope.unallocated")+ "(" + FacilityTreeAttributeConstant.UNALLOCATED_SCOPE + ")" );
 			
+			// 返り値を生成
 			ret = new Object[2][facilityIdList.size()];
 			ret[PropertyConstant.SELECT_VALUE] = facilityIdList.toArray();
 			ret[PropertyConstant.SELECT_DISP_TEXT] = facilityNameList.toArray();
